searchData={"items":[{"type":"module","title":"TextDiff","doc":"Formats the diff between two strings.","ref":"TextDiff.html"},{"type":"module","title":"Examples - TextDiff","doc":"iex> code = \"\"\"\n    ...> defmodule Foo do\n    ...>   @moduledoc   false\n    ...>\n    ...>   def foo, do:  :foo\n    ...>\n    ...>   def three_times(x) do\n    ...>     {x,\n    ...>      x,x}\n    ...>   end\n    ...>\n    ...>   def bar(x) do\n    ...>     {:bar, x}\n    ...>   end\n    ...> end\\\n    ...> \"\"\"\n    ...> formatted = code |> Code.format_string!() |> IO.iodata_to_binary()\n    ...> code\n    ...> |> TextDiff.format(formatted, color: false)\n    ...> |> IO.iodata_to_binary()\n    \"\"\"\n     1  1   |defmodule Foo do\n     2    - |  @moduledoc   false\n        2 + |  @moduledoc false\n     3  3   |\n     4    - |  def foo, do:  :foo\n        4 + |  def foo, do: :foo\n     5  5   |\n     6  6   |  def three_times(x) do\n     7    - |    {x,\n     8    - |     x,x}\n        7 + |    {x, x, x}\n     9  8   |  end\n    10  9   |\n         ...|\n    \"\"\"","ref":"TextDiff.html#module-examples"},{"type":"function","title":"TextDiff.default_opts/0","doc":"","ref":"TextDiff.html#default_opts/0"},{"type":"function","title":"TextDiff.format/3","doc":"Formats the diff between two strings.\n\nThe returned `iodata` shows the lines with changes and 2 lines before and\nafter the changed positions. The string contains also a gutter with line\nnumber and a `-` or `+` for removed and added lines. Multiple lines without\nchanges are marked with `...` in the gutter.","ref":"TextDiff.html#format/3"},{"type":"function","title":"Options - TextDiff.format/3","doc":"* `:after` - the count of lines printed after each change. Defaults to `2`.\n  * `:before` - the count of lines printed before each change. Defaults to `2`.\n  * `:color` - enables color in the output. Defaults to `true`.\n  * `:line_numbers` - enables line numbers. Defaults to `true`.\n  * `:line` - the line number of the first line. Defaults to `1`.\n  * `:tokenizer` - a function that splits a line of text into distinct tokens\n    that should be compared when creating a colorized diff of a single line.\n    The default tokenizer prioritizes highlighting entire words, so a line\n    that updates `two` to `three` would appear as removing `two` and adding\n    `three`, instead of keeping the `t`, removing `wo`, and adding `hree`.\n    `:tokenizer` may be a function that accepts a single argument or an MFA\n    tuple, where the line of text will be prepended to the given arguments.\n  * `:colorizer` - a function that accepts a string and a color token (`:red`,\n    `:green`, etc.) and returns iodata with that formatting applied. May be\n    a function that accepts 2 arguments or an MFA tuple, where the string and\n    color will be prepended to the given arguments. Defaults to a colorizer\n    based on `IO.ANSI.format/1`.\n  * `:format` - optional keyword list of formatting options. See \"Formatting\"\n    below.","ref":"TextDiff.html#format/3-options"},{"type":"function","title":"Formatting - TextDiff.format/3","doc":"Alternative formatting options can be passed to control the gutter, colors,\nand the separator between the gutter and line of text in the rendered diff.\nThe separator is the same for all lines, but the gutter and colors differ\ndepending on the operation: `:eq`, `:del`, `:ins`, `:skip`.\n\nThe options (and their defaults) are:\n\n  * `:separator` - `\"|\"`\n  * `:gutter`\n    * `:eq` - `\"   \"`\n    * `:del` - `\" - \"`\n    * `:ins` - `\" + \"`\n    * `:skip` - `\"...\"`\n  * `:colors`\n    * `:del` - `[text: :red, space: :red_background]`\n    * `:ins` - `[text: :green, space: :green_background]`\n    * `:skip` - `[text: :yellow]`\n    * `:separator` - `[text: :yellow]`\n\nThese top-level formatting options will be merged into passed options. For\nexample, you could change only the `:separator` with:\n\n    format(string1, string2, format: [separator: \"~ \"])\n\nSee `IO.ANSI` for info on colors.","ref":"TextDiff.html#format/3-formatting"},{"type":"function","title":"Examples - TextDiff.format/3","doc":"iex> code = \"\"\"\n    ...> defmodule Bar do\n    ...>   @moduledoc false\n    ...>\n    ...>   bar(x, y) do\n    ...>     z = x + y\n    ...>     {x,y  , z}\n    ...>   end\n    ...>\n    ...>   bar(x, y, z) do\n    ...>     {x, y, z}\n    ...>   end\n    ...> end\\\n    ...> \"\"\"\n    iex> formatted = code |> Code.format_string!() |> IO.iodata_to_binary()\n    iex> code\n    ...> |> TextDiff.format(formatted, color: false)\n    ...> |> IO.iodata_to_binary()\n    \"\"\"\n         ...|\n     4  4   |  bar(x, y) do\n     5  5   |    z = x + y\n     6    - |    {x,y  , z}\n        6 + |    {x, y, z}\n     7  7   |  end\n     8  8   |\n         ...|\n    \"\"\"\n    iex> code\n    ...> |> TextDiff.format(formatted, color: false, after: 1, before: 1)\n    ...> |> IO.iodata_to_binary()\n    \"\"\"\n         ...|\n     5  5   |    z = x + y\n     6    - |    {x,y  , z}\n        6 + |    {x, y, z}\n     7  7   |  end\n         ...|\n    \"\"\"\n    iex> code\n    ...> |> TextDiff.format(formatted, color: false, line_numbers: false)\n    ...> |> IO.iodata_to_binary()\n    \"\"\"\n    ...|\n       |  bar(x, y) do\n       |    z = x + y\n     - |    {x,y  , z}\n     + |    {x, y, z}\n       |  end\n       |\n    ...|\n    \"\"\"","ref":"TextDiff.html#format/3-examples"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,50]}}